@@ -33,6 +33,6 @@ void dns_setgrent(void *opts);
 void dns_endgrent(void *opts);
 struct group *dns_getgrent(void *opts);
 struct group *dns_getgrgid(gid_t gid, void *opts);
-struct group *dns_getgrnam(char *name, void *opts);
+struct group *dns_getgrnam(const char *name, void *opts);
 
 #endif
