@@ -32,12 +32,9 @@
 extern void dns_sethostent(int stayopen, void *opts);
 extern void dns_endhostent(void *opts);
 extern struct hostent *dns_gethostent(void *opts);
-extern struct hostent *dns_gethostbyname(char *name, void *opts);
-extern struct hostent *dns_gethostbyaddr(char *addr,
+extern struct hostent *dns_gethostbyname(const char *name, void *opts);
+extern struct hostent *dns_gethostbyaddr(const char *addr,
 					 int len, int type,
 					 void *opts);
 
 #endif
-
-
-
