@@ -47,7 +47,7 @@ struct netent *dns_getnetent(void *opts)
 }
 
 
-struct netent *dns_getnetbyname(char *name, void *opts)
+struct netent *dns_getnetbyname(const char *name, void *opts)
 {
     errno = ECONNREFUSED;
     return NULL;
