@@ -32,11 +32,8 @@
 extern void dns_setnetent(int stayopen, void *opts);
 extern void dns_endnetent(void *opts);
 extern struct netent *dns_getnetent(void *opts);
-extern struct netent *dns_getnetbyname(char *name, void *opts);
+extern struct netent *dns_getnetbyname(const char *name, void *opts);
 extern struct netent *dns_getnetbyaddr(long net, int type,
 				       void *opts);
 
 #endif
-
-
-
