@@ -33,7 +33,7 @@ extern void dns_setpwent(void *opts);
 extern void dns_endpwent(void *opts);
 extern struct passwd *dns_getpwent(void *opts);
 extern struct passwd *dns_getpwuid(uid_t uid, void *opts);
-extern struct passwd *dns_getpwnam(char *name, void *opts);
+extern struct passwd *dns_getpwnam(const char *name, void *opts);
 
 #endif
 
