@@ -47,8 +47,8 @@ struct protoent *dns_getprotoent(void *opts)
 }
 
 
-struct protoent *dns_getprotobyname(char *name,
-				void *opts)
+struct protoent *dns_getprotobyname(const char *name,
+				    void *opts)
 {
     errno = ECONNREFUSED;
     return NULL;
