@@ -32,10 +32,10 @@
 extern void dns_setprotoent(int stayopen, void *opts);
 extern void dns_endprotoent(void *opts);
 extern struct protoent *dns_getprotoent(void *opts);
-extern struct protoent *dns_getprotobyname(char *name,
-				       void *opts);
+extern struct protoent *dns_getprotobyname(const char *name,
+					   void *opts);
 extern struct protoent *dns_getprotobynumber(int number,
-					 void *opts);
+					     void *opts);
 
 #endif
 
