@@ -47,7 +47,7 @@ struct rpcent *dns_getrpcent(void *opts)
 }
 
 
-struct rpcent *dns_getrpcbyname(char *name,
+struct rpcent *dns_getrpcbyname(const char *name,
 				void *opts)
 {
     errno = ECONNREFUSED;
