@@ -32,7 +32,7 @@
 extern void dns_setrpcent(int stayopen, void *opts);
 extern void dns_endrpcent(void *opts);
 extern struct rpcent *dns_getrpcent(void *opts);
-extern struct rpcent *dns_getrpcbyname(char *name,
+extern struct rpcent *dns_getrpcbyname(const char *name,
 				       void *opts);
 extern struct rpcent *dns_getrpcbynumber(int number,
 					 void *opts);
