@@ -32,9 +32,6 @@
 extern void dns_setspent(void *opts);
 extern void dns_endspent(void *opts);
 extern struct spwd *dns_getspent(void *opts);
-extern struct spwd *dns_getspnam(char *name, void *opts);
+extern struct spwd *dns_getspnam(const char *name, void *opts);
 
 #endif
-
-
-
