@@ -33,6 +33,6 @@ void nis_setgrent(void *opts);
 void nis_endgrent(void *opts);
 struct group *nis_getgrent(void *opts);
 struct group *nis_getgrgid(gid_t gid, void *opts);
-struct group *nis_getgrnam(char *name, void *opts);
+struct group *nis_getgrnam(const char *name, void *opts);
 
 #endif
