@@ -47,14 +47,14 @@ struct hostent *nis_gethostent(void *opts)
 }
 
 
-struct hostent *nis_gethostbyname(char *name, void *opts)
+struct hostent *nis_gethostbyname(const char *name, void *opts)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct hostent *nis_gethostbyaddr(char *addr,
+struct hostent *nis_gethostbyaddr(const char *addr,
 				  int len, int type,
 				  void *opts)
 {
