@@ -32,12 +32,9 @@
 extern void nis_sethostent(int stayopen, void *opts);
 extern void nis_endhostent(void *opts);
 extern struct hostent *nis_gethostent(void *opts);
-extern struct hostent *nis_gethostbyname(char *name, void *opts);
-extern struct hostent *nis_gethostbyaddr(char *addr,
+extern struct hostent *nis_gethostbyname(const char *name, void *opts);
+extern struct hostent *nis_gethostbyaddr(const char *addr,
 					 int len, int type,
 					 void *opts);
 
 #endif
-
-
-
