@@ -47,7 +47,7 @@ struct netent *nis_getnetent(void *opts)
 }
 
 
-struct netent *nis_getnetbyname(char *name, void *opts)
+struct netent *nis_getnetbyname(const char *name, void *opts)
 {
     errno = ECONNREFUSED;
     return NULL;
