@@ -32,11 +32,8 @@
 extern void nis_setnetent(int stayopen, void *opts);
 extern void nis_endnetent(void *opts);
 extern struct netent *nis_getnetent(void *opts);
-extern struct netent *nis_getnetbyname(char *name, void *opts);
+extern struct netent *nis_getnetbyname(const char *name, void *opts);
 extern struct netent *nis_getnetbyaddr(long net, int type,
 				       void *opts);
 
 #endif
-
-
-
