@@ -57,7 +57,7 @@ struct passwd *nis_getpwuid(uid_t uid, void *opts)
 }
 
 
-struct passwd *nis_getpwnam(char *name, void *opts)
+struct passwd *nis_getpwnam(const char *name, void *opts)
 {
     errno = ECONNREFUSED;
     return NULL;
