@@ -33,7 +33,7 @@ extern void nis_setpwent(void *opts);
 extern void nis_endpwent(void *opts);
 extern struct passwd *nis_getpwent(void *opts);
 extern struct passwd *nis_getpwuid(uid_t uid, void *opts);
-extern struct passwd *nis_getpwnam(char *name, void *opts);
+extern struct passwd *nis_getpwnam(const char *name, void *opts);
 
 #endif
 
