@@ -32,11 +32,11 @@
 extern void nis_setservent(int stayopen, void *opts);
 extern void nis_endservent(void *opts);
 extern struct servent *nis_getservent(void *opts);
-extern struct servent *nis_getservbyname(char *name,
-					 char *protocol,
+extern struct servent *nis_getservbyname(const char *name,
+					 const char *protocol,
 					 void *opts);
 extern struct servent *nis_getservbyport(int port,
-					 char *protocol,
+					 const char *protocol,
 					 void *opts);
 
 #endif
