@@ -50,7 +50,7 @@ struct spwd *nis_getspent(void *opts)
 }
 
 
-struct spwd *nis_getspnam(char *name, void *opts)
+struct spwd *nis_getspnam(const char *name, void *opts)
 {
     errno = ECONNREFUSED;
     return NULL;
