@@ -32,9 +32,6 @@
 extern void nis_setspent(void *opts);
 extern void nis_endspent(void *opts);
 extern struct spwd *nis_getspent(void *opts);
-extern struct spwd *nis_getspnam(char *name, void *opts);
+extern struct spwd *nis_getspnam(const char *name, void *opts);
 
 #endif
-
-
-
