@@ -42,7 +42,7 @@
 void _ENSWF(_setservent)(int stayopen);
 void _ENSWF(_endservent)(void);
 struct servent * _ENSWF(_getservent)(void);
-struct servent * _ENSWF(_getservbyname)(char *name, char *protocol);
-struct servent * _ENSWF(_getservbyport)(int port, char *protocol);
+struct servent * _ENSWF(_getservbyname)(const char *name,const char *protocol);
+struct servent * _ENSWF(_getservbyport)(int port, const char *protocol);
 
 #endif
