@@ -82,7 +82,7 @@ static struct group *grent_parse(char *str, int len)
     char *cp;
     
 
-    if (Xalloc(&pbuf, len) == NULL)
+    if (Xalloc(&pbuf, len+8) == NULL)
 	return NULL;
 
     strncpy(pbuf, str, len);
@@ -206,7 +206,7 @@ struct group *yp_getgrgid(gid_t gid, char *opts)
 }
 
 
-struct group *yp_getgrnam(char *name, char *opts)
+struct group *yp_getgrnam(const char *name, char *opts)
 {
     struct group *gr;
     char *map;
