@@ -35,7 +35,7 @@ extern void yp_setgrent(char *opts);
 extern void yp_endgrent(char *opts);
 extern struct group *yp_getgrent(char *opts);
 extern struct group *yp_getgrgid(gid_t gid, char *opts);
-extern struct group *yp_getgrnam(char *name, char *opts);
+extern struct group *yp_getgrnam(const char *name, char *opts);
 
 #endif
 
