@@ -41,8 +41,6 @@
 #include "yp_hosts.h"
 #include "rpcsvc/ypclnt.h"
 
-#include "xalloc.h"
-
 static int rewind_flag = 1;
 static char *savekey = NULL;
 static int savekeylen = 0;
@@ -57,7 +55,7 @@ static struct hostent *hostent_parse(char *str, int len)
     int i;
     
 
-    if (Xalloc(&pbuf, len) == NULL)
+    if (Xalloc(&pbuf, len+8) == NULL)
 	return NULL;
     
     strncpy(pbuf, str, len);
@@ -171,7 +169,8 @@ struct hostent *yp_gethostent(void *opts)
 }
 
 
-struct hostent *yp_gethostbyaddr(char *addr, int alen, int type, void *opts)
+struct hostent *yp_gethostbyaddr(const char *addr,
+				 int alen, int type, void *opts)
 {
     struct hostent *host;
     char *map;
@@ -202,7 +201,8 @@ struct hostent *yp_gethostbyaddr(char *addr, int alen, int type, void *opts)
 }
 
 
-struct hostent *yp_gethostbyname(char *name, void *opts)
+struct hostent *yp_gethostbyname(const char *name,
+				 void *opts)
 {
     struct hostent *host;
     char *map;
