@@ -34,12 +34,9 @@ extern void yp_sethostent(int stayopen, void *opts);
 /* extern void yp_sethostent(void *opts);  */
 extern void yp_endhostent(void *opts);
 extern struct hostent *yp_gethostent(void *opts);
-extern struct hostent *yp_gethostbyname(char *name, void *opts);
-extern struct hostent *yp_gethostbyaddr(char *addr,
+extern struct hostent *yp_gethostbyname(const char *name, void *opts);
+extern struct hostent *yp_gethostbyaddr(const char *addr,
 					 int len, int type,
 					 void *opts);
 
 #endif
-
-
-
