@@ -60,7 +60,7 @@ char *_yp_strip_names(char *buff)
    return buff;
 }
 
-
+#if 0
 char *_yp_printaddr(unsigned long addr)
 {
    /*
@@ -77,8 +77,8 @@ char *_yp_printaddr(unsigned long addr)
    sprintf(buffer, "%d.%d.%d.%d", a, b, c, d);
    return buffer;
 }
-
-
+#endif
+#if 0
 unsigned long _yp_readaddr(char *buff)
 {
    /*
@@ -95,7 +95,7 @@ unsigned long _yp_readaddr(char *buff)
 
    return addr;
 }
-
+#endif
 
 char *_yp_xcopy(char **cp, char *str)
 {
