@@ -34,12 +34,6 @@ extern void yp_setnetent(int stayopen, void *opts);
 extern void yp_endnetent(void *opts);
 extern struct netent *yp_getnetent(void *opts);
 extern struct netent *yp_getnetbyaddr(long net, int type, void *opts);
-extern struct netent *yp_getnetbyname(char *name, void *opts);
+extern struct netent *yp_getnetbyname(const char *name, void *opts);
 
 #endif
-
-
-
-
-
-
