@@ -51,7 +51,7 @@ static struct passwd *pwent_parse(char *str, int len)
     char *cp;
 
     
-    if (Xalloc(&pbuf, len) == NULL)
+    if (Xalloc(&pbuf, len+8) == NULL)
 	return NULL;
     
     strncpy(pbuf, str, len);
@@ -211,7 +211,7 @@ struct passwd *yp_getpwuid(uid_t uid, void *opts)
 }
 
 
-struct passwd *yp_getpwnam(char *name, void *opts)
+struct passwd *yp_getpwnam(const char *name, void *opts)
 {
     struct passwd *pw;
     char *map;
