@@ -33,7 +33,7 @@ extern void yp_setpwent(void *opts);
 extern void yp_endpwent(void *opts);
 extern struct passwd *yp_getpwent(void *opts);
 extern struct passwd *yp_getpwuid(uid_t uid, void *opts);
-extern struct passwd *yp_getpwnam(char *name, void *opts);
+extern struct passwd *yp_getpwnam(const char *name, void *opts);
 
 #endif
 
