@@ -32,7 +32,7 @@
 extern void yp_setrpcent(int stayopen, void *opts);
 extern void yp_endrpcent(void *opts);
 extern struct rpcent *yp_getrpcent(void *opts);
-extern struct rpcent *yp_getrpcbyname(char *name,
+extern struct rpcent *yp_getrpcbyname(const char *name,
 				       void *opts);
 extern struct rpcent *yp_getrpcbynumber(int number,
 					 void *opts);
