@@ -51,7 +51,7 @@ static struct servent *servent_parse(char *str, int len)
     int i;
     
     
-    if (Xalloc(&pbuf, len) == NULL)
+    if (Xalloc(&pbuf, len+8) == NULL)
 	return NULL;
     
     strncpy(pbuf, str, len);
@@ -187,8 +187,8 @@ struct servent *yp_getservent(void *opts)
 **
 ** This is *not* an efficient way to do it...
 */
-struct servent *yp_getservbyname(char *name,
-				 char *protocol,
+struct servent *yp_getservbyname(const char *name,
+				 const char *protocol,
 				 void *opts)
 {
     struct servent *sp;
@@ -207,7 +207,7 @@ struct servent *yp_getservbyname(char *name,
 
 
 struct servent *yp_getservbyport(int port,
-				 char *protocol,
+				 const char *protocol,
 				 void *opts)
 {
     struct servent *sp;
