@@ -32,12 +32,12 @@
 extern void yp_setservent(int stayopen, void *opts);
 extern void yp_endservent(void *opts);
 extern struct servent *yp_getservent(void *opts);
-extern struct servent *yp_getservbyname(char *name,
-					 char *protocol,
-					 void *opts);
+extern struct servent *yp_getservbyname(const char *name,
+					const char *protocol,
+					void *opts);
 extern struct servent *yp_getservbyport(int port,
-					 char *protocol,
-					 void *opts);
+					const char *protocol,
+					void *opts);
 
 #endif
 
