@@ -32,9 +32,6 @@
 extern void yp_setspent(void *opts);
 extern void yp_endspent(void *opts);
 extern struct spwd *yp_getspent(void *opts);
-extern struct spwd *yp_getspnam(char *name, void *opts);
+extern struct spwd *yp_getspnam(const char *name, void *opts);
 
 #endif
-
-
-
