@@ -37,63 +37,6 @@
 
 extern void print_network(struct netent *);
 
-#ifdef HAVE_BUGGY_INET_NETWORK
-static int _inet_network(char *cp)
-{
-    int v[4];
-    int res;
-    int len;
-    int i;
-
-    
-    v[0] = v[1] = v[2] = v[3] = 0;
-
-    len = sscanf(cp, "%d.%d.%d.%d", &v[0], &v[1], &v[2], &v[3]);
-    if (len <= 0)
-	return -1;
-    
-    res = 0;
-
-    
-    for (i = 0; i < len; i++)
-    {
-	res <<= 8;
-	res += v[i];
-    }
-    
-    return res;
-}
-
-#ifdef inet_network
-#undef inet_network
-#endif
-#define inet_network _inet_network
-
-
-static struct in_addr _inet_makeaddr(int net, int host)
-{
-    struct in_addr in;
-    long addr;
-
-    
-    addr = net;
-    if (addr != 0)
-    {
-	while ((addr & (0xFF << 24)) == 0)
-	    addr <<= 8;
-    }
-
-    addr |= host;
-
-    in.s_addr = htonl(addr);
-    return in;
-}
-
-#ifdef inet_makeaddr
-#undef inet_makeaddr
-#endif
-#define inet_makeaddr _inet_makeaddr
-#endif
 
 
 int
