@@ -173,7 +173,7 @@ struct yp_conf *ypconf_read(char *path)
 
 
 
-char *ypconf_domain2address(char *domain, int *idx)
+char *ypconf_domain2address(const char *domain, int *idx)
 {
     int i;
 
@@ -203,7 +203,9 @@ char *ypconf_domain2address(char *domain, int *idx)
 }
 
 
-CLIENT *ypconf_domain2client(char *domain, int *idx, char **address)
+CLIENT *ypconf_domain2client(const char *domain,
+			     int *idx,
+			     char **address)
 {
     int i;
     CLIENT *clh;
