@@ -54,7 +54,9 @@ extern void ypconf_end(void);
 extern void ypconf_free(struct yp_conf *ncp);
 extern struct yp_conf *ypconf_read(char *path);
 
-extern char *ypconf_domain2address(char *domain, int *idx);
-extern CLIENT *ypconf_domain2client(char *domain, int *idx, char **address);
+extern char *ypconf_domain2address(const char *domain, int *idx);
+extern CLIENT *ypconf_domain2client(const char *domain,
+				    int *idx,
+				    char **address);
 
 #endif
